@@ -73,8 +73,7 @@ Encoder::~Encoder()
     }
 
     if (m_avCodecContext) {
-        avcodec_close(m_avCodecContext);
-        av_free(m_avCodecContext);
+        avcodec_free_context(&m_avCodecContext);
     }
 }
 
@@ -185,8 +184,12 @@ void Encoder::setEncodingPreference(PipeWireBaseEncodedStream::EncodingPreferenc
     m_encodingPreference = preference;
 }
 
-void Encoder::applyEncodingPreference(AVDictionary *options)
+AVDictionary *Encoder::buildEncodingOptions()
 {
+    AVDictionary *options = NULL;
+
+    av_dict_set_int(&options, "threads", qMin(16, QThread::idealThreadCount()), 0);
+
     switch (m_encodingPreference) {
     case PipeWireBaseEncodedStream::EncodingPreference::NoPreference:
         av_dict_set(&options, "preset", "veryfast", 0);
@@ -205,6 +208,18 @@ void Encoder::applyEncodingPreference(AVDictionary *options)
         av_dict_set(&options, "preset", "veryfast", 0);
         break;
     }
+
+    return options;
+}
+
+void Encoder::maybeLogOptions(AVDictionary *options)
+{
+    if (PIPEWIRERECORD_LOGGING().isInfoEnabled()) {
+        char *buffer = NULL;
+        av_dict_get_string(options, &buffer, '=', ',');
+        qCInfo(PIPEWIRERECORD_LOGGING) << "Using encoding options:" << buffer;
+        av_freep(&buffer);
+    }
 }
 
 SoftwareEncoder::SoftwareEncoder(PipeWireProduce *produce)
