@@ -57,8 +57,8 @@ bool LibVpxEncoder::initialize(const QSize &size)
         m_avCodecContext->global_quality = 35;
     }
 
-    AVDictionary *options = nullptr;
-    applyEncodingPreference(options);
+    AVDictionary *options = buildEncodingOptions();
+    maybeLogOptions(options);
 
     if (int result = avcodec_open2(m_avCodecContext, codec, &options); result < 0) {
         qCWarning(PIPEWIRERECORD_LOGGING) << "Could not open codec" << av_err2str(result);
@@ -78,9 +78,10 @@ int LibVpxEncoder::percentageToAbsoluteQuality(const std::optional<quint8> &qual
     return std::max(1, int(MinQuality - (m_quality.value() / 100.0) * MinQuality));
 }
 
-void LibVpxEncoder::applyEncodingPreference(AVDictionary *options)
+AVDictionary *LibVpxEncoder::buildEncodingOptions()
 {
-    av_dict_set_int(&options, "threads", qMin(16, QThread::idealThreadCount()), 0);
+    AVDictionary *options = SoftwareEncoder::buildEncodingOptions();
+
     av_dict_set(&options, "preset", "veryfast", 0);
     av_dict_set(&options, "tune-content", "screen", 0);
     av_dict_set(&options, "deadline", "realtime", 0);
@@ -91,4 +92,6 @@ void LibVpxEncoder::applyEncodingPreference(AVDictionary *options)
     // Disable in-loop filtering
     av_dict_set(&options, "-flags", "+loop", 0);
     av_dict_set(&options, "crf", "45", 0);
+
+    return options;
 }
