@@ -50,9 +50,8 @@ bool LibVpxVp9Encoder::initialize(const QSize &size)
     m_avCodecContext->pix_fmt = AV_PIX_FMT_YUV420P;
     m_avCodecContext->time_base = AVRational{1, 1000};
 
-    AVDictionary *options = nullptr;
-
-    applyEncodingPreference(options);
+    AVDictionary *options = buildEncodingOptions();
+    maybeLogOptions(options);
 
     const auto area = size.width() * size.height();
     // m_avCodecContext->framerate is not set, so we use m_produce->maxFramerate() instead.
@@ -61,16 +60,6 @@ bool LibVpxVp9Encoder::initialize(const QSize &size)
 
     m_avCodecContext->gop_size = fps * 2;
 
-    // TODO: Make bitrate depend on the framerate? More frames is more data.
-    // maxFramerate can apparently be changed while recording, so keep that in mind.
-    m_avCodecContext->bit_rate = std::round(area * 2);
-    m_avCodecContext->rc_min_rate = std::round(area);
-    m_avCodecContext->rc_max_rate = std::round(area * 3);
-
-    m_avCodecContext->rc_buffer_size = m_avCodecContext->bit_rate;
-
-    m_avCodecContext->thread_count = QThread::idealThreadCount();
-
     if (int result = avcodec_open2(m_avCodecContext, codec, &options); result < 0) {
         qCWarning(PIPEWIRERECORD_LOGGING) << "Could not open codec" << av_err2str(result);
         return false;
@@ -89,8 +78,10 @@ int LibVpxVp9Encoder::percentageToAbsoluteQuality(const std::optional<quint8> &q
     return std::max(1, int(MinQuality - (m_quality.value() / 100.0) * MinQuality));
 }
 
-void LibVpxVp9Encoder::applyEncodingPreference(AVDictionary *options)
+AVDictionary *LibVpxVp9Encoder::buildEncodingOptions()
 {
+    AVDictionary *options = SoftwareEncoder::buildEncodingOptions();
+
     // We're probably capturing a screen
     av_dict_set(&options, "tune-content", "screen", 0);
 
@@ -99,8 +90,9 @@ void LibVpxVp9Encoder::applyEncodingPreference(AVDictionary *options)
     if (m_quality) {
         crf = percentageToAbsoluteQuality(m_quality);
     }
-    m_avCodecContext->qmin = std::clamp(crf / 2, 0, crf);
-    m_avCodecContext->qmax = std::clamp(qRound(crf * 1.5), crf, 63);
+
+    av_dict_set_int(&options, "qmin", std::clamp(crf / 2, 0, crf), 0);
+    av_dict_set_int(&options, "qmax", std::clamp(int(crf * 1.5), crf, 63), 0);
     av_dict_set_int(&options, "crf", crf, 0);
 
     // 0-4 are for Video-On-Demand with the good or best deadline.
@@ -116,7 +108,8 @@ void LibVpxVp9Encoder::applyEncodingPreference(AVDictionary *options)
     av_dict_set(&options, "tile-columns", "6", 0);
     av_dict_set(&options, "tile-rows", "2", 0);
 
-    // This should make things faster, but it only seems to consume 100MB more RAM.
-    // av_dict_set(&options, "row-mt", "1", 0);
+    av_dict_set(&options, "row-mt", "1", 0);
     av_dict_set(&options, "frame-parallel", "1", 0);
+
+    return options;
 }
